@@ -43,7 +43,7 @@ class Api(object):
 
     def register(self, child, name=None):
         if name is None:
-            name = getattr(child, 'api_name', child.__class__.__name__.lower())
+            name = getattr(child, 'api_name', child.__name__.lower())
         if name in self.children:
             raise Warning(
                 'Publisher with name "%s" already registered: %r -> %r' % (
@@ -56,6 +56,12 @@ APIS = {}
 
 
 def register(name, *args):
+    if not args:
+        # We've been called as a decorator
+        def wrapper(cls, name=name):
+            register(name, cls)
+            return cls
+        return wrapper
     try:
         api = APIS[name]
     except KeyError:
