@@ -4,7 +4,6 @@ from __future__ import unicode_literals
 from functools import wraps
 from . import http
 
-
 def permit(test_func):
     '''Decorate a handler to control access'''
     def decorator(view_func):
@@ -17,11 +16,11 @@ def permit(test_func):
     return decorator
 
 permit_logged_in = permit(
-    lambda self, request, *args, **kwargs: request.user.is_authenticated()
+    lambda self, *args, **kwargs: self.request.user.is_authenticated()
 )
 
 permit_staff = permit(
-    lambda self, request, *args, **kwargs: request.user.is_staff
+    lambda self, *args, **kwargs: self.request.user.is_staff
 )
 
 
@@ -29,5 +28,5 @@ def permit_groups(*groups):
     def in_groups(request, *args):
         return request.user.groups.filter(name__in=args).exists()
     return permit(
-        lambda self, request, *args, **kwargs: in_groups(request, *groups)
+        lambda self, *args, **kwargs: in_groups(self.request, *groups)
     )
