@@ -1,8 +1,9 @@
 from __future__ import unicode_literals
 
-from . import fields, http
-from .serialiser import MetaSerialiser, Serialiser
+from . import fields
+from .meta import Meta
 from .publisher import Publisher
+from .serialiser import MetaSerialiser, Serialiser
 
 from six import with_metaclass
 
@@ -20,7 +21,32 @@ for f in dir(fields):
     except TypeError:
         pass
 
+
+class ModelMeta(Meta):
+    model = None
+    # Fields to include from the Model
+    fields = []
+    field_types = {}
+    # Fields to exclude from the Model
+    exclude = []
+    # Fields from the model to flag as read-only
+    read_only_fields = []
+
+    # When restoring an object, which fields do we treat as m2m?
+    related_fields = []
+    # When we try to retrieve an instance, which fields do we use?
+    key_fields = ('id',)
+    # When restoring an object, which attrs do we not use
+    ignored_fields = ()
+    # When calling get_or_create, what do we pass as defaults?
+    defaults = {}
+    # Are there any deserialised fields we must pass to get_or_create defaults?
+    core_fields = ()
+
+
 class MetaModelSerialiser(MetaSerialiser):
+    meta_class = ModelMeta
+
     def __new__(mcs, name, bases, attrs):
 
         new_class = super(MetaModelSerialiser, mcs).__new__(mcs, name, bases, attrs)
@@ -32,11 +58,8 @@ class MetaModelSerialiser(MetaSerialiser):
         current_fields = new_class._fields.keys()
 
         model_fields = {}
-        try:
-            model = new_class._meta.model
-        except AttributeError:
-            pass
-        else:
+        model = new_class._meta.model
+        if model is not None:
             for field in model._meta.fields:
                 # If we've got one, skip...
                 if field.name in current_fields:
@@ -57,7 +80,10 @@ class MetaModelSerialiser(MetaSerialiser):
                 if not field.default is NOT_PROVIDED:
                     kwargs['default'] = field.default
 
-                field_class = FIELD_MAP.get(field.__class__.__name__, fields.Field)
+                try:
+                    field_class = new_class._meta.field_types[field.name]
+                except KeyError:
+                    field_class = FIELD_MAP.get(field.__class__.__name__, fields.Field)
                 model_fields[field.name ] = field_class(**kwargs)
 
         new_class._fields.update(model_fields)
@@ -78,6 +104,61 @@ class ModelSerialiser(with_metaclass(MetaModelSerialiser, Serialiser)):
         return instance
 
 
+class ModelReadSerialiser(ModelSerialiser):
+    '''
+    A Serialiser that will only Read, not Create, an instance on inflate.
+
+    Specify only the fields you intend to filter by.
+    '''
+
+    def restore_object(self, objdata, instance, **kwargs):
+        try:
+            return self._meta.model.objects.get(**objdata)
+        except self._meta.model.DoesNotExist:
+            raise fields.ValidationError('%s with values %r does not exist.' % (
+                self._meta.model.__name__,
+                objdata,
+            ))
+
+
+class ModelCreateUpdateSerialiser(ModelSerialiser):
+
+    '''
+    A ModelSerialiser with the ability to create/update instances from data.
+    '''
+
+    def restore_object(self, objdata, instance, **kwargs):
+        related = {
+            key: objdata.pop(key)
+            for key in self._meta.related_fields
+        }
+
+        if instance is None:
+            lookup = {
+                field: objdata[field]
+                for field in self._meta.key_fields
+            }
+            defaults = dict(self._meta.defaults)
+            for key in self._meta.core_fields:
+                defaults[key] = objdata[key]
+            instance, _ = self._meta.model.objects.get_or_create(
+                defaults=defaults,
+                **lookup
+            )
+
+        for key, value in objdata.items():
+            if key in self._meta.ignored_fields:
+                continue
+            setattr(instance, key, value)
+
+        instance.save()
+
+        for key, value in related.items():
+            getattr(instance, key).add(*value)
+
+        return instance
+
+
 class ModelPublisher(Publisher):
     '''A Publisher with useful methods to publish Models'''
 
@@ -96,73 +177,6 @@ class ModelPublisher(Publisher):
         return get_object_or_404(self.get_object_list(), pk=object_id)
 
 
-
-class ModelFormMixin(object):
-    '''Provide writable models using form validation'''
-
-    initial = {}
-    form_class = None
-
-    # Here we mimic the FormMixin from django
-    def get_initial(self):
-        """
-        Returns the initial data to use for forms on this view.
-        """
-        return self.initial.copy()
-
-    def get_form_class(self):
-        """
-        Returns the form class to use in this view
-        """
-        return self.form_class
-
-    def get_form(self, form_class):
-        """
-        Returns an instance of the form to be used in this view.
-        """
-        return form_class(**self.get_form_kwargs())
-
-    def get_form_kwargs(self, **kwargs):
-        """
-        Returns the keyword arguments for instantiating the form.
-        """
-        kwargs.setdefault('initial', self.get_initial())
-        if self.request.method in ('POST', 'PUT'):
-            kwargs.update({
-                'data': self.request.POST,
-                'files': self.request.FILES,
-            })
-        return kwargs
-
-    def list_post_default(self, request, *args, **kwargs):
-        form_class = self.get_form_class()
-        form = self.get_form(form_class)
-
-        if form.is_valid():
-            obj = form.save()
-            return self.render_single_object(obj)
-
-        # return errors
-
-
-    def object_put_default(self, request, object_id, *args, **kwargs):
-        obj = self.get_object(object_id)
-        form_class = self.get_form_class()
-        form = self.get_form(form_class, instance=obj)
-
-        if form.is_valid():
-            obj = form.save()
-            return self.render_single_object(obj)
-
-        # return errors
-
-    def object_delete_default(self, request, object_id, *args, **kwargs):
-        obj = self.get_object(object_id)
-        # XXX Some sort of verification?
-        obj.delete()
-        return http.NoContent()
-
-
 def modelserialiser_factory(name, model, **kwargs):
     attrs = {
         'model': model,
@@ -176,6 +190,7 @@ def modelserialiser_factory(name, model, **kwargs):
     meta = type(str('Meta'), (object,), attrs)
     return type(ModelSerialiser)(str(name), (ModelSerialiser,), {'Meta': meta})
 
+
 class ModelSerialiserField(fields.SerialiserField):
     def __init__(self, *args, **kwargs):
         if not 'serialiser' in kwargs:
@@ -183,6 +198,7 @@ class ModelSerialiserField(fields.SerialiserField):
             kwargs['serialiser'] = modelserialiser_factory(model.__name__ + 'Serialiser', model, **kwargs)()
         super(ModelSerialiserField, self).__init__(*args, **kwargs)
 
+
 class ModelManySerialiserField(fields.ManySerialiserField):
     def __init__(self, *args, **kwargs):
         if not 'serialiser' in kwargs:
