@@ -6,6 +6,7 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.http import require_http_methods
 from django.views.decorators.csrf import ensure_csrf_cookie, csrf_exempt
 
+from cgi import parse_header
 from collections import defaultdict
 try:
     import ujson as json
@@ -62,10 +63,9 @@ class BasePublisher(object):
         '''
         view = cls.build_view()
 
+        name = getattr(cls, 'api_name', cls.__name__.lower())
         if api_name:
-            name = '%s_%s' % (api_name, cls.api_name)
-        else:
-            name = cls.api_name
+            name = '%s_%s' % (api_name, name)
 
         return [
             url(r'^object/(?P<object_id>%s)/(?P<action>%s)/(?P<argument>%s)/?$' % (cls.OBJECT_PATTERN, cls.ACTION_PATTERN, cls.ARGUMENT_PATTERN),
@@ -158,10 +158,9 @@ class SimplePatternsMixin(object):
     def patterns(cls, api_name=None):
         view = cls.build_view()
 
+        name = getattr(cls, 'api_name', cls.__name__.lower())
         if api_name:
-            name = '%s_%s' % (api_name, cls.api_name)
-        else:
-            name = cls.api_name
+            name = '%s_%s' % (api_name, name)
 
         return [
             url(r'^(?P<object_id>\d+)/(?P<action>\w+)/(?P<argument>.+?)/?$',
@@ -244,7 +243,6 @@ class Publisher(BasePublisher):
         return object_list
 
     # Pagination
-
     def get_page(self, object_list):
         '''Return a paginated object list, along with some metadata'''
         page_size = getattr(self, 'page_size', None)
@@ -296,8 +294,8 @@ class Publisher(BasePublisher):
 
     def get_request_data(self, default=None):
         '''Retrieve data from request'''
-        ctype = self.request.META.get('CONTENT_TYPE', '').split(';')[0].strip()
-        if ctype in self.CONTENT_TYPES:
+        content_type, _ = parse_header(self.request.META.get('CONTENT_TYPE', ''))
+        if content_type in self.CONTENT_TYPES:
             if not self.request.body:
                 return default
             return self.loads(self.request.body)
